/* 

        Copyright (C) 1995
        Free Software Foundation, Inc.

   This file is part of GNU cfengine - written and maintained 
   by Mark Burgess, Dept of Computing and Engineering, Oslo College,
   Dept. of Theoretical physics, University of Oslo
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any
   later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

*/

/*******************************************************************/
/*                                                                 */
/* File Image copying                                              */
/*                                                                 */
/* client part for remote copying                                  */
/*                                                                 */
/*******************************************************************/

#define INET 1

#include "cf.defs.h"
#include "cf.extern.h"

/*********************************************************************/

IdentifyForVerification(sd,ip_string,fqname)

int sd;
char *ip_string, *fqname;

{ char sendbuff[bufsize];
  int n;

bzero(sendbuff,bufsize);

sprintf(sendbuff,"AUTH %s %s",ip_string,fqname);

if ((n = send(sd,sendbuff,bufsize,0)) != bufsize)
   {
   sprintf(OUTPUT,"socket verify only sent %d bytes\n",n);
   CfLog(cferror,OUTPUT,"send");
   return false;
   }

return true;
}
